<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pa">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="55"/>
        <source>Deepin Home</source>
        <translation>ਡੀਪਿਨ ਹੋਮ</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="57"/>
        <source>Show main window</source>
        <translation>ਮੁੱਖ ਵਿੰਡੋ ਵੇਖਾਓ</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="72"/>
        <source>Communication</source>
        <translation>ਸੰਚਾਰ</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="75"/>
        <source>Exit</source>
        <translation>ਬਾਹਰ</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="315"/>
        <source>View</source>
        <translation>ਵੇਖੋ</translation>
    </message>
</context>
</TS>